conftrak

`conftrak` is a light-weight beamline configuration and parameters storage and tracker.

Based on NSLS-II [Amostra](https://github.com/NSLS-II/amostra).

Quick start:
```
python startup.py --mongo-host=localhost --mongo-port=27017 --database=conftrak --service-port=7771 --timezone=US/Eastern
```

Badges:
[![CircleCI](https://circleci.com/gh/hhslepicka/conftrak.svg?style=svg)](https://circleci.com/gh/hhslepicka/conftrak)
[![Build Status](https://travis-ci.org/hhslepicka/conftrak.svg?branch=master)](https://travis-ci.org/hhslepicka/conftrak)
[![codecov](https://codecov.io/gh/hhslepicka/conftrak/branch/master/graph/badge.svg)](https://codecov.io/gh/hhslepicka/conftrak)
[![Coverage Status](https://coveralls.io/repos/github/hhslepicka/conftrak/badge.svg?branch=master)](https://coveralls.io/github/hhslepicka/conftrak?branch=master)
[![Code Health](https://landscape.io/github/hhslepicka/conftrak/master/landscape.svg?style=flat)](https://landscape.io/github/hhslepicka/conftrak/master)

